	*May 2016
	version 14.1
	set more off
	capture log close 
	global dhsEtdata D:\Users\khirvonen\Documents\Data\DHS\Ethiopia\2011\data
	global results D:\Users\khirvonen\Documents\Dropbox (IFPRI)\research\dds_rural_urban 
	 
	 
	log using "$results/Hirvonen_DDS_poisson_decomposition", replace text

/*

This do file runs the analysis in 
"Rural-urban differences in children's dietary diversity in Ethiopia: a Poisson decomposition analysis"
by Kalle Hirvonen, Published in Economics Letters 2016, www.kallehirvonen.com


*/
 
************************************************************************************************************************************** 
 *Ethiopia - DHS - 2011 (available after registration at http://dhsprogram.com):
 
	use "$dhsEtdata\ETKR61FL.DTA", clear
	ren v000 hv000
	ren v001 hv001
	ren v002 hv002
	d hv000 hv001 hv002
	 
	merge m:1 hv000 hv001 hv002 using "$dhsEtdata\ETHR61FL.DTA",keepusing(hv246?)
	assert _m!=1
	keep if _m==3
	drop _m hv246i hv246j hv246k hv246a
 ************************************************************************************************************************************** 

**************************************************************************************************************************************
*PREPARE DATA + BASIC CLEANING:
	
	*restrict the sample to children between 6 and 23 months:
	ren  hw1 agem 
	keep if inrange(agem, 6,23)
	ren hv001 v001
	  
	foreach v of varlist hv246b hv246c hv246d hv246e hv246f hv246g hv246h {
	replace `v'=1 if inrange(`v', 1, 91)
	replace `v'=. if `v'>91
	 }
	  
	ren hv246b cows
	replace cows=1 if hv246e==1
	replace cows=1 if hv246d==1
	label var cows "owns cows, bulls, bulls, goats or sheep"
	ren hv246f chicken
	drop hv246d

	 
	ren v025 urban
	 

	gen sw=1/v005
	 
	foreach v of varlist  v411 v414? {
	replace `v'=. if `v'>1
	}
	 
	 
	*no deceased children:
	assert b5==1
	
	*compute dietary diversity score (basic 7-point):
	 
	*1 Grains, roots and tubers	
	gen FG1=v414e==1
	replace FG1=. if v414e==.   
	replace FG1=1 if v414f==1 
	 
	*2 Legumes and nuts	
	gen FG2=v414o==1
	replace FG2=. if v414o==.
	 
	*3 Dairy products	
	gen FG3=v414p==1
	replace FG3=. if v414p==.
	replace FG3=1 if v414v==1
	replace FG3=1 if v411==1
	 
	*4 Poultry, fish, meat	
	gen FG4=v414h==1
	replace FG4=. if v414h==.
	replace FG4=1 if v414m==1
	replace FG4=1 if v414n==1
	replace FG4=. if v414h==.


	*5 Eggs	
	gen FG5=v414g==1
	replace FG5=. if v414g==.
	 
	*6 Vitamin A rich fruits and vegetables	
	gen FG6=v414i==1
	replace FG6=. if v414i==.
	replace FG6=1 if v414j==1
	replace FG6=1 if v414k==1
	replace FG6=. if v414i==.

	  
	 *7 Other fruits and vegetables
	gen FG7=v414l==1
	replace FG7=. if v414l==.

	egen num_mis=rowmiss(FG1 FG2 FG3 FG4 FG5 FG6 FG7)
	
	tab num_mis ,m
	*drop if missing observations:
	keep if num_mis==0
	 
	egen nFGC=rowtotal(FG?)

	count

	sum nFGC
	tab nFGC
	  
	*generate sample-weight:
	generate wgt = v005/1000000
	 

	assert v106!=.
	tab v106, gen(educm)
	replace educm3=1 if educm4==1
	label var educm3 "mothers education: secondary or higher"
	*tab v701, gen(educf)
	ren v012 momage
	replace urban=0 if urban==2
	gen rural=urban==0
	gen ANC4p=0 
	replace ANC4p=1 if m14>3
	replace ANC4p=. if m14==98
	replace ANC4p=0 if m14==.

	gen femhead=v151==2
	tab v190, gen(w_)
	gen female=b4==2
	label define female 1 "female" 0 "male"
	label values female female
	label define urban 1 "urban" 0 "rural"
	label values urban urban

	count
	 
	
	 
	gen orthodox=v130==1
	gen muslim=v130==4
	tab v107
 
	replace v107=0 if v107==.
	ren v107 momeducyrs
 
	tab v702
	replace v702=0 if v702==.
	replace v702=. if v702==99
	ren v702 dadeducyrs 

	ren v191 assind
	label var 	assind	"DHS asset index"	
	label var	FG1	"1 Grains, roots and tubers"
	label var	FG2	"2 Legumes and nuts"
	label var	FG3	"3 Dairy products"
	label var	FG4	"4 Poultry, fish, meat"
	label var	FG5	"5 Eggs"
	label var	FG6	"6 Vitamin A rich fruits and vegetables"
	label var	FG7	"7 Other fruits and vegetables"
	label var	nFGC	"dietary diversity score"
	label var	wgt	"survey weight"
	label var	educm1	"mother has no education"
	label var	educm2	"mother has primary education"
	label var	educm3	"mother has secondary or higher education"
	label var	ANC4p	"4 or more antenatal visits"
	label var	femhead	"female headed household"
	label var	w_1	"wealth index: poorest"
	label var	w_2	"wealth index: poorer"
	label var	w_3	"wealth index: middle"
	label var	w_4	"wealth index: richer"
	label var	w_5	"wealth index: richest"
	label var	female	"female child"
	label var	agem	"age in months"
	label var	momage	"mother's age"
	label var 	urban "urban"
	label var 	urban "rural"
	label var 	dadeducyrs "paternal education (yrs)"
	label var 	momeducyrs "maternal education (yrs)"
**************************************************************************************************************************************
*Restruct the sample to kids for who we have all data:

 	reg nFGC agem female momage ANC4p cows   chicken  assind momeducyrs dadeducyrs 
	keep if e(sample)==1
	
**************************************************************************************************************************************
*FIGURE-1:

	nbvargr nFGC, scheme(s1mono)
	graph export "$results/fitting_poisson.tif", replace width(600)
**************************************************************************************************************************************
  
**************************************************************************************************************************************
*TABLE-1: 


	estpost  tabstat    nFGC agem female momeducyrs dadeducyrs momage ANC4p assind  cows   chicken  [aweight=wgt]  , by(urban) statistics(mean sd) columns(statistics)    
	esttab using "$results/sumstat_ls", main(mean) aux(sd) nostar unstack noobs nonote rtf label replace   nogaps  

	foreach v of varlist nFGC agem female momeducyrs dadeducyrs momage ANC4p assind  cows   chicken {
	d `v'


	ttest `v'  ,by(rural)

	}
	 
**************************************************************************************************************************************
	 

**************************************************************************************************************************************
*TABLE-2:
	*Note: this command can be downloaded from Myeong-Su Yun's website: http://www.tulane.edu/~msyun/research.htm
	mvdcmp  rural   : poisson nFGC agem female momeducyrs dadeducyrs momage ANC4p assind  cows   chicken 
**************************************************************************************************************************************
 
 

 
log close 
